@@ -312,31 +312,9 @@ static char * parse_options (struct fsck_data * data, int argc, char * argv [])
 ** a working hard drive, copy the file system from the bad **\n\
 ** drive  to the good one -- dd_rescue is  a good tool for **\n\
 ** that -- and only then run this program.                 **\n\
-** If you are using the latest reiserfsprogs and  it fails **\n\
-** please  email bug reports to reiserfs-list@namesys.com, **\n\
-** providing  as  much  information  as  possible --  your **\n\
-** hardware,  kernel,  patches,  settings,  all reiserfsck **\n\
-** messages  (including version),  the reiserfsck logfile, **\n\
-** check  the  syslog file  for  any  related information. **\n\
-** If you would like advice on using this program, support **\n\
-** is available  for $25 at  www.namesys.com/support.html. **\n\
 *************************************************************\n\
 \nWill rebuild the filesystem (%s) tree\n"
 
-#define START_WARNING \
-"*************************************************************\n\
-** If you are using the latest reiserfsprogs and  it fails **\n\
-** please  email bug reports to reiserfs-list@namesys.com, **\n\
-** providing  as  much  information  as  possible --  your **\n\
-** hardware,  kernel,  patches,  settings,  all reiserfsck **\n\
-** messages  (including version),  the reiserfsck logfile, **\n\
-** check  the  syslog file  for  any  related information. **\n\
-** If you would like advice on using this program, support **\n\
-** is available  for $25 at  www.namesys.com/support.html. **\n\
-*************************************************************\n\
-\n"
-
-
 void warn_what_will_be_done (char * file_name, struct fsck_data * data)
 {
     FILE * warn_to;
@@ -345,8 +323,6 @@ void warn_what_will_be_done (char * file_name, struct fsck_data * data)
 
     if (data->mode == FSCK_REBUILD)
 	reiserfs_warning (warn_to, REBUILD_WARNING, file_name);
-    else
-	reiserfs_warning (warn_to, START_WARNING);
     
     /* warn about fsck mode */
     switch (data->mode) {
@@ -421,8 +397,9 @@ void warn_what_will_be_done (char * file_name, struct fsck_data * data)
 	(data->log == stdout) ? "stdout" : 
 	(data->log_file_name ? data->log_file_name : "fsck.run"));
     
-    if (!(data->options & OPT_YES) && !user_confirmed (warn_to, "\nDo you want to "
-	"run this program?[N/Yes] (note need to type Yes if you do):", "Yes\n"))
+    if (!(data->options & OPT_YES) && !(data->options & OPT_SILENT) &&
+	!user_confirmed (warn_to, "\nDo you want to run this program?[N/Yes] "
+	"(note need to type Yes if you do):", "Yes\n"))
 	exit (EXIT_USER);
 }
 
@@ -751,11 +728,8 @@ static void reiserfsck_replay_journal (reiserfs_filsys_t * fs) {
 
 static int the_end (reiserfs_filsys_t * fs)
 {
-    struct reiserfs_super_block * sb;
     int ret = EXIT_FIXED;
 
-    sb = fs->fs_ondisk_sb;
-
     /* put bitmap and objectid map on place */
     reiserfs_delete_bitmap (fs->fs_bitmap2);
     fs->fs_bitmap2 = fsck_new_bitmap (fs);
@@ -967,7 +941,7 @@ static int reiserfs_check_auto_state(reiserfs_filsys_t *fs)
 	}
 
 	if (interval != UINT_MAX && now > lastcheck + interval) {
-		fprintf(stderr, "File system hasn't been checked in %u days. "
+		fprintf(stderr, "File system hasn't been checked in %lu days. "
 		        "Checking now.\n", (now - lastcheck) / (60*60*24));
 		return 1;
 	}
